netapp_ontap.resources.qos_option API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.qos_option`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Quality of Service Options

A QoS option represents a configuration detail that is used by QoS.

## Examples

### Retrieving a QoS option from the cluster

The following example retrieves the QoS option in the cluster.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import QosOption

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = QosOption()
        resource.get(return_timeout=0)
        print(resource)

### 2) Update a QoS option

The following example shows how to modify the background task reserve policy to 40%.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import QosOption

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = QosOption()
        resource.background_task_reserve = 40
        resource.patch(hydrate=True, return_timeout=0)

## Classes

`class QosOption (*args, **kwargs)`

  Allows interaction with QosOption objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves QoS options. This option is available only at diagnostic privilege level and above.

    ### Related ONTAP commands

    - `qos settings cluster-options show`

    ### Learn more

    - `DOC /storage/qos/qos-options`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Update a specific QoS option. This option is available only at diagnostic privilege level and above.

    ### Related ONTAP commands

    - `qos settings cluster-options modify`

    ### Learn more

    - `DOC /storage/qos/qos-options`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class QosOptionSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the QosOption object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `background_task_reserve: Size GET POST PATCH`

    Percentage reserve for critical background tasks.

    Example: 33

  `links: SelfLink GET`

    The links field of the qos_option.